{message}

{form_open}
<div class="control-group">
    <label class="control-label" for="moduleFolder"><?php echo $this->lang->line('Module catalog'); ?></label>
    <div class="controls">
        <input type="text" id="moduleFolder" name="moduleFolder" placeholder="<?php echo $this->lang->line('Enter module catalog'); ?>" value="{moduleFolderValue}" />
    </div>
</div>
<div class="control-group">
    <label class="control-label" for="moduleName"><?php echo $this->lang->line('Module name'); ?></label>
    <div class="controls">
        <input type="text" id="moduleName" name="moduleName" placeholder="<?php echo $this->lang->line('Enter module name'); ?>" value="{moduleNameValue}" />
    </div>
</div>
<fieldset>
    <legend><?php echo $this->lang->line('Static files'); ?></legend>
    <div class="control-group">
        <div class="controls">
            <?php echo form_checkbox('create_config_file', '1', $this->input->post('create_config_file')) . ' ' . $this->lang->line('Create configuration file'); ?>
        </div>
    </div>
    <div class="control-group">
        <div class="controls">
            <?php echo form_checkbox('create_lang_file', '1', $this->input->post('create_lang_file')) . ' ' . $this->lang->line('Create language file'); ?>
        </div>
    </div>
    <div class="control-group">
        <div class="controls">
            <?php echo form_checkbox('create_sql_file', '1', $this->input->post('create_sql_file')) . ' ' . $this->lang->line('Create dummy SQL file'); ?>
        </div>
    </div>
</fieldset>
<?php foreach ($chunk as $fieldset => $elements) : ?>
    <fieldset>
        <legend><?php echo $fieldset; ?></legend>
        <?php foreach ($elements as $elem) : ?>
            <?php echo $elem; ?>
        <?php endforeach; ?>
    </fieldset>
<?php endforeach; ?>
<div class="form-actions">
    <input type="submit" class="btn btn-primary" value="<?php echo $this->lang->line('Create module'); ?>" name="send"/>
</div>
{form_close}