<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['crud_field_templates'] = array(
    'name' => array(
        'field' => 'name',
        'display_as' => 'Name',
        'callback' => 'ccc_edit_link',
        'not_null' => '1',
        'in_column' => '1',
    ),
    'title' => array(
        'field' => 'title',
        'display_as' => 'Title',
        'callback' => 'ccc_edit_link',
        'not_null' => '1',
        'in_column' => '1',
    ),
    'photo' => array(
        'field' => 'photo',
        'display_as' => 'Photo',
        'callback' => 'ccc_set_image_upload',
        'not_null' => '',
        'in_column' => '1',
    ),
    'date' => array(
        'field' => 'date',
        'display_as' => 'Date',
        'callback' => 'ccc_datetime',
        'not_null' => '',
        'in_column' => '1',
    ),
    'view_order' => array(
        'field' => 'view_order',
        'display_as' => 'View order',
        'callback' => 'ccc_view_order',
        'not_null' => '',
        'in_column' => '1',
    ),
    'active' => array(
        'field' => 'active',
        'display_as' => 'Active',
        'callback' => 'ccc_active',
        'not_null' => '',
        'in_column' => '1',
    ),
    'text' => array(
        'field' => 'text',
        'display_as' => 'Text',
        'callback' => 'ccc_texteditor',
        'not_null' => '',
        'in_column' => '',
    ),
    'seo_t' => array(
        'field' => 'seo_t',
        'display_as' => 'SEO title',
        'callback' => 'ccc_input',
        'not_null' => '',
        'in_column' => '',
    ),
    'seo_k' => array(
        'field' => 'seo_k',
        'display_as' => 'SEO keywords',
        'callback' => 'ccc_textarea',
        'not_null' => '',
        'in_column' => '',
    ),
    'seo_d' => array(
        'field' => 'seo_d',
        'display_as' => 'SEO description',
        'callback' => 'ccc_textarea',
        'not_null' => '',
        'in_column' => '',
    ),
    'url' => array(
        'field' => 'url',
        'display_as' => 'Url',
        'callback' => 'ccc_url',
        'not_null' => '',
        'in_column' => '',
    ),
    'id_resource_type_page' => array(
        'field' => 'id_resource_type_page',
        'display_as' => 'Page',
        'callback' => 'ccc_respage',
        'not_null' => '',
        'in_column' => '',
    ),
    'file' => array(
        'field' => 'file',
        'display_as' => 'File',
        'callback' => 'ccc_file',
        'not_null' => '',
        'in_column' => '',
    ),
    'email' => array(
        'field' => 'email',
        'display_as' => 'Email',
        'callback' => 'ccc_email',
        'not_null' => '',
        'in_column' => '1',
    ),
);
