<?php

class ccc_respage_run extends crud_callback_chunk_run
{

    public function get_callback_string()
    {
        return '$this->load->library(\'resmng/respage_rtgrid\', [\'crud\' => $this->crud, \'alias_field\' => \'title\', \'id_resource_type_page_template\' => 1, \'parent_id\' => 3]);';
    }

}

class ccc_respage implements crud_callback_chunk
{

    public function get_name()
    {
        return 'Page for resource manager';
    }

    public function get_options()
    {
        return new crud_callback_chunk_options();
    }

    public function get_schema()
    {
        return 'int(11)';
    }

    public function run()
    {
        return new ccc_respage_run();
    }

}
