<?php

return[
    'developer_docs' => [
        'pages' => [
            'module_creator' => [
                'label'        => 'Создатель модулей',
                'file'         => __DIR__ . '/../docs/module_creator/module_creator.md',
                'position'     => 20,
                'acl_resource' => 'skeleton',
                'acl_action'   => 'edit_skeleton',
                'pages'        => [
                    'create_module' => [
                        'label'    => 'Создать модуль',
                        'file'     => __DIR__ . '/../docs/module_creator/create_module.md',
                        'position' => 10,
                        'uri'      => 'skeleton/index',
                    ],
                    'create_crud'   => [
                        'label'    => 'CRUD генератор',
                        'file'     => __DIR__ . '/../docs/module_creator/create_crud.md',
                        'position' => 20,
                        'uri'      => 'skeleton/crud',
                    ]
                ]
            ],
            'core_parsers'   => [
                'pages' => [
                    'dev_view_parser' => [
                        'label'        => 'Загрузка содержимого view-файла (dev_view)',
                        'file'         => __DIR__ . '/../docs/parser/dev_view.md',
                        'position'     => 30,
                        'acl_resource' => 'skeleton',
                        'acl_action'   => 'edit_skeleton',
                    ]
                ]
            ]
        ],
    ],
];
